==> haskell-xml-hamlet-0.4.1.1-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1.1
id: xml-hamlet-0.4.1.1-1GGgmyz5Jt26SyWcZyZhdC
key: xml-hamlet-0.4.1.1-1GGgmyz5Jt26SyWcZyZhdC
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: fa61c0f308f1c5ccc991ab1c33b6b14a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-hamlet-0.4.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-hamlet-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xml-hamlet-0.4.1.1
hs-libraries: HSxml-hamlet-0.4.1.1-1GGgmyz5Jt26SyWcZyZhdC
depends:
    base-4.10.1.0 shakespeare-2.0.14.1-32rsjeN2mIRIMjIopzvj3C
    xml-conduit-1.7.1.2-6gFQiws3x8MLTlTZidb1ra
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj template-haskell-2.12.0.0
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7 containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             shakespeare-2.0.14.1-32rsjeN2mIRIMjIopzvj3C=eaf7442dcf4f06e8465f8a7c8329e0a1
             xml-conduit-1.7.1.2-6gFQiws3x8MLTlTZidb1ra=21d9e81735218f62ef130b0585c8e2ee
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=5b8a6db8c81629fde3a12212030372e3
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.4.1.1-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1.1
id: xml-hamlet-0.4.1.1-AOGhGWz3lxb6PTPblANZyj
key: xml-hamlet-0.4.1.1-AOGhGWz3lxb6PTPblANZyj
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: bd28241d94d3a9345c1a958baa497923
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xml-hamlet-0.4.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/xml-hamlet-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/xml-hamlet-0.4.1.1
hs-libraries: HSxml-hamlet-0.4.1.1-AOGhGWz3lxb6PTPblANZyj
depends:
    base-4.10.1.0 shakespeare-2.0.14.1-F9ZMtelONK91m6N6iRt61y
    xml-conduit-1.7.1.2-H3ZpzTAmvzr4lA9GzRYPA2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj template-haskell-2.12.0.0
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7 containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             shakespeare-2.0.14.1-F9ZMtelONK91m6N6iRt61y=e81dfb107090b7a1f4db570c5496a2f4
             xml-conduit-1.7.1.2-H3ZpzTAmvzr4lA9GzRYPA2=ce072e3dade188a3f4d6d5057ee8a96e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=5b8a6db8c81629fde3a12212030372e3
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
